# Support for external parameters:
#
# rpmbuild -ba desktop-base-openmamba.spec \
#    --define="distroID OpenMamba" --define="distroid openmamba" \
#    --define "distroicon openmamba"
# autospec -u desktop-base-openmamba -a5 \
#    --define distroID=OpenMamba,distroid=openmamba,distroicon=openmamba.png

%define with_kde3 0
%ifnarch arm
%define with_kde3tools 1
%else
%define with_kde3tools 0
%endif

%define kdedir %(echo `kde-config --prefix`)

%define distroID   openmamba
%define distroid   openmamba
%define distroicon openmamba

Name:          desktop-base-openmamba
Version:       2.4.7
Release:       1mamba
Summary:       openmamba default desktop theme and menu entries
Group:         System/Tools
Vendor:        openmamba
Distribution:  openmamba
Packager:      Silvan Calarco <silvan.calarco@mambasoft.it>
URL:           http://www.openmamba.org
Source:        http://www.openmamba.org/distribution/sources/desktop-base-openmamba-%{version}.tar.bz2
License:       GPL
## AUTOBUILDREQ-BEGIN
## AUTOBUILDREQ-END
%if "%{with_kde3tools}" == "1"
# For rpm macros used below:
BuildRequires: kdelibs3-devel
%endif
Requires:      ttf-bitstream-vera
Requires:      ttf-freefont
#Requires:      openmamba-sound-theme
Requires:      networkmanagergui
Requires:      system-base-openmamba = %{?epoch:%epoch:}%{version}-%{release}
Requires:      xscreensaver
Requires:      /usr/bin/notify-send
Requires:      license-dialog
Requires:      udisks
%if "%{with_kde3tools}" == "1"
Requires:      kommander
%endif
%ifnarch arm
Requires:      postplug-xorg
Requires:      postplug-sound
# NOTE: b43-tools is required by b43-firmware net-SRPM package
Requires:      b43-tools
%endif
Provides:      libflashsupport
Obsoletes:     libflashsupport
Requires:      usbinstall
Requires:      dmz-cursor-themes
Requires:      ipheth
Requires:      alsa-oss
Requires:      polkit
Requires:      pulseaudio
BuildRoot:     %{_tmppath}/%{name}-%{version}-root

%description
openmamba default desktop theme and menu entries providing with various desktop related scripts and configuration files.

%package -n system-base-openmamba
Group:         System/Tools
Summary:       openmamba base tools for non graphical system
Requires:      cabextract
Requires:      curl
Requires:      wget >= 1.14-2mamba
Requires:      diffutils
Requires:      file
Requires:      /usr/bin/strip
Requires:      bash-completion
#Requires:      /usr/bin/b43-fwcutter
Requires:      pm-utils
%ifarch %{ix86} x86_64
Requires:      grub-theme-openmamba
%endif
%ifnarch arm
Requires:      smartmontools
%endif
Requires:      openmamba-release
Requires:      sudo
# for sun-java7
Requires:      jpackage-utils
Requires:      systemd
Requires:      pam
Requires:      dbus
Requires:      avahi
Requires:      vixie-cron

%description -n system-base-openmamba
openmamba base tools for non graphical system.

%prep
%setup -q

%build
%make \
   ARCH=%{_target_cpu} \
   DISTROID=%{distroID} DISTROid=%{distroid} \
   DISTROICON=%{distroicon} \
   WITHKDE3=%{with_kde3} \
   WITHKDE3TOOLS=%{with_kde3tools}

%install
[ "%{buildroot}" != / ] && rm -rf %{buildroot}
%makeinstall \
   ARCH=%{_target_cpu} \
   DISTROID=%{distroID} DISTROid=%{distroid} \
   DISTROICON=%{distroicon} \
   WITHKDE3=%{with_kde3} \
   WITHKDE3TOOLS=%{with_kde3tools}

%find_lang mambabase
%find_lang mambawelcome
%find_lang bootrecover
%find_lang openmamba-update

cat mambawelcome.lang bootrecover.lang >> mambabase.lang

install -d -m0755 %{buildroot}%{_sysconfdir}/udev/rules.d
ln -s /dev/null %{buildroot}%{_sysconfdir}/udev/rules.d/80-net-setup-link.rules

%clean
[ "%{buildroot}" != / ] && rm -rf %{buildroot}

%files -n system-base-openmamba -f openmamba-update.lang
%defattr(-,root,root)
%{_sysconfdir}/udev/rules.d/80-net-setup-link.rules
%config %{_sysconfdir}/profile.d/proxy.sh
%{_sysconfdir}/sudoers.d/proxy
%config (noreplace) %{_sysconfdir}/sysconfig/proxy
%config %{_sysconfdir}/sysconfig/netsrpminstall
%config %{_sysconfdir}/prelink.conf.d/skype.conf
%{_bindir}/openmamba-makereport
%{_bindir}/openmamba-netsrpms
%{_bindir}/openmamba-update
%attr(0755,root,root) %{_datadir}/%{distroid}/bin/*
%{_datadir}/%{distroid}/SRPMS/*
%{_datadir}/%{distroid}/bootrecover/bootrecover.sh
%{_datadir}/%{distroid}/mambabase/mambabase.db
%{_datadir}/%{distroid}/mambabase/mambabase.sh
%{_datadir}/pixmaps/system-logo-white.png

%files -f mambabase.lang
%defattr(-,root,root)
%{_sysconfdir}/xdg/menus/applications-merged/%{distroid}.menu
%{_sysconfdir}/polkit-1/localauthority/10-vendor.d/60-desktop-policy.pkla
%{_sysconfdir}/xprofile.d/qt-graphicssystem.sh
%{_datadir}/applications/*.desktop
%{_datadir}/desktop-directories/%{distroID}.directory
%{_datadir}/desktop-directories/%{distroID}-Logs.directory
%{_datadir}/desktop-directories/%{distroID}-NetInstall.directory
%{_datadir}/icons/hicolor/*/apps/distromenu-chromium.png
%{_datadir}/icons/hicolor/*/apps/distromenu-flash.png
%{_datadir}/icons/hicolor/*/apps/distromenu-java.png
%{_datadir}/icons/hicolor/*/apps/distromenu-netinstall.png
%{_datadir}/icons/hicolor/*/apps/distromenu-skype.png
%{_datadir}/icons/hicolor/*/apps/distromenu-spotify.png
%{_datadir}/icons/hicolor/*/apps/%{distroicon}.png
%{_datadir}/icons/hicolor/*/apps/mamba.png
%{_datadir}/%{distroid}/images/openmamba_skydome.png
%{_datadir}/%{distroid}/images/openmamba_top.png
%{_datadir}/%{distroid}/images/openmamba_bottom.png
#%{_kde4_bindir}/konsole-nofork
%if "%{with_kde3}" == "1"
%{_kdedatadir}/apps/konqueror/profiles/resourcesbrowsing
%{_kdedatadir}/apps/kdisplay/color-schemes/openmamba_green.kcsrc
%{_kdedatadir}/apps/kthememanager/themes/openmamba-green/openmamba-green.xml
%{_kdedatadir}/apps/kthememanager/themes/openmamba-green/openmamba-green.preview.png
%{_kdedatadir}/autostart/kmix.desktop
%{_kdedatadir}/config/kcmartsrc
%{_kdedatadir}/config/kcmfonts
%{_kdedatadir}/config/kdeglobals
%{_kdedatadir}/config/kmilodrc
%{_kdedatadir}/config/kmixrc
%{_kdedatadir}/config/knotifyrc
%{_kdedatadir}/config/kwinrc
%{_kdedatadir}/config/kickerrc
%{_kdedatadir}/config/kdesktoprc
%{_kdedatadir}/config/kcmthememanagerrc
%{_kdedatadir}/config/konsolerc
%{_kdedatadir}/config/kpagerrc
%{_kdedatadir}/config/compizrc
%{_kdedatadir}/wallpapers/*
%endif
%if "%{with_kde3tools}" == "1"
# mambabase stuff
%{_datadir}/%{distroid}/mambabase/mambabase-autostart.desktop
%{_datadir}/%{distroid}/mambabase/mambabase.kmdr
# mambawelcome stuff
/lib/systemd/system/mambawelcome.target
/lib/systemd/system/mambawelcome.service
%{_datadir}/%{distroid}/mambawelcome/*
%{_datadir}/icons/hicolor/*/apps/mambawelcome.png
# bootrecover stuff
%{_datadir}/icons/hicolor/*/apps/bootrecover.png
%{_datadir}/openmamba/bootrecover/bootrecover.kmdr
%{_datadir}/openmamba/mambareport/mambareport.kmdr
%{_kdedatadir}/config/kcmfonts
%{_kdedatadir}/config/kdeglobals
%endif
# desktop stuff
%{_sysconfdir}/xprofile.d/desktop-firsttime.sh
%{_datadir}/openmamba/desktop/desktop-common.tar.bz2
%{_datadir}/openmamba/desktop/desktop-*.tar.bz2

%changelog
* Fri Sep 19 2014 Silvan Calarco <silvan.calarco@mambasoft.it> 2.4.7-1mamba
- update to 2.4.7

* Tue Sep 16 2014 Silvan Calarco <silvan.calarco@mambasoft.it> 2.4.6-1mamba
- update to 2.4.6

* Sat Sep 06 2014 Silvan Calarco <silvan.calarco@mambasoft.it> 2.4.5-3mamba
- require pulseaudio

* Mon Aug 11 2014 Silvan Calarco <silvan.calarco@mambasoft.it> 2.4.5-2mamba
- restore lost specfile changes from 2.4.2-4mamba to 2.4.2-6mamba

* Thu Aug 07 2014 Silvan Calarco <silvan.calarco@mambasoft.it> 2.4.5-1mamba
- update to 2.4.5

* Tue Aug 05 2014 Silvan Calarco <silvan.calarco@mambasoft.it> 2.4.4-1mamba
- update to 2.4.4

* Thu Jul 24 2014 Silvan Calarco <silvan.calarco@mambasoft.it> 2.4.3-1mamba
- update to 2.4.3

* Sat May 10 2014 Silvan Calarco <silvan.calarco@mambasoft.it> 2.4.2-6mamba
- system-base-openmamba: require vixie-cron

* Fri May 02 2014 Silvan Calarco <silvan.calarco@mambasoft.it> 2.4.2-5mamba
- desktop-base-openmamba: require avahi

* Tue Apr 29 2014 Silvan Calarco <silvan.calarco@mambasoft.it> 2.4.2-4mamba
- provide /etc/udev/rules.d/80-net-setup-link.rules symlink to /dev/null to restore traditional network interface naming

* Sun Apr 27 2014 Silvan Calarco <silvan.calarco@mambasoft.it> 2.4.2-3mamba
- require dbus and polkit

* Wed Apr 23 2014 Silvan Calarco <silvan.calarco@mambasoft.it> 2.4.2-2mamba
- system-base-openmamba: require pam

* Wed Mar 26 2014 Silvan Calarco <silvan.calarco@mambasoft.it> 2.4.2-1mamba
- update to 2.4.2

* Thu Feb 13 2014 Silvan Calarco <silvan.calarco@mambasoft.it> 2.4.1-1mamba
- update to 2.4.1

* Fri Jan 17 2014 Silvan Calarco <silvan.calarco@mambasoft.it> 2.4.0-1mamba
- update to 2.4.0

* Sun Nov 03 2013 Silvan Calarco <silvan.calarco@mambasoft.it> 2.3.99-1mamba
- update to 2.3.99

* Sun Sep 01 2013 Silvan Calarco <silvan.calarco@mambasoft.it> 2.3.98-1mamba
- update to 2.3.98

* Sun Sep 01 2013 Silvan Calarco <silvan.calarco@mambasoft.it> 2.3.97-1mamba
- update to 2.3.97

* Sat Jul 27 2013 Silvan Calarco <silvan.calarco@mambasoft.it> 2.3.96-1mamba
- update to 2.3.96

* Wed Jul 03 2013 Silvan Calarco <silvan.calarco@mambasoft.it> 2.3.95-1mamba
- update to 2.3.95

* Fri Jun 28 2013 Silvan Calarco <silvan.calarco@mambasoft.it> 2.3.94-1mamba
- update to 2.3.94

* Tue Jun 25 2013 Silvan Calarco <silvan.calarco@mambasoft.it> 2.3.93-1mamba
- update to 2.3.93

* Wed Jun 12 2013 Silvan Calarco <silvan.calarco@mambasoft.it> 2.3.92-1mamba
- update to 2.3.92

* Wed May 22 2013 Silvan Calarco <silvan.calarco@mambasoft.it> 2.3.91-1mamba
- update to 2.3.91

* Sat May 18 2013 Silvan Calarco <silvan.calarco@mambasoft.it> 2.3.90-1mamba
- update to 2.3.90

* Tue May 14 2013 Silvan Calarco <silvan.calarco@mambasoft.it> 2.3.21.1-2mamba
- require systemd completing sysv5 -> systemd transition

* Fri May 03 2013 Silvan Calarco <silvan.calarco@mambasoft.it> 2.3.21.1-1mamba
- update to 2.3.21.1

* Thu May 02 2013 Silvan Calarco <silvan.calarco@mambasoft.it> 2.3.21-1mamba
- update to 2.3.21

* Thu Apr 18 2013 Silvan Calarco <silvan.calarco@mambasoft.it> 2.3.20-1mamba
- update to 2.3.20

* Wed Apr 10 2013 Silvan Calarco <silvan.calarco@mambasoft.it> 2.3.19-1mamba
- update to 2.3.19

* Wed Apr 03 2013 Silvan Calarco <silvan.calarco@mambasoft.it> 2.3.18-1mamba
- update to 2.3.18

* Sun Feb 10 2013 Silvan Calarco <silvan.calarco@mambasoft.it> 2.3.17-1mamba
- update to 2.3.17

* Mon Feb 04 2013 Silvan Calarco <silvan.calarco@mambasoft.it> 2.3.16.1-1mamba
- update to 2.3.16.1

* Mon Feb 04 2013 Silvan Calarco <silvan.calarco@mambasoft.it> 2.3.16-1mamba
- update to 2.3.16

* Mon Dec 10 2012 Silvan Calarco <silvan.calarco@mambasoft.it> 2.3.15-1mamba
- update to 2.3.15

* Mon Nov 26 2012 Silvan Calarco <silvan.calarco@mambasoft.it> 2.3.14-1mamba
- update to 2.3.14

* Wed Nov 21 2012 Silvan Calarco <silvan.calarco@mambasoft.it> 2.3.13-2mamba
- don't require kernelsound and kernelwireless

* Sat Nov 10 2012 Silvan Calarco <silvan.calarco@mambasoft.it> 2.3.13-1mamba
- update to 2.3.13
- require wget >= 1.14-2mamba for libproxy support

* Wed Sep 19 2012 Silvan Calarco <silvan.calarco@mambasoft.it> 2.3.12-1mamba
- update to 2.3.12

* Thu Aug 23 2012 Silvan Calarco <silvan.calarco@mambasoft.it> 2.3.11.1-1mamba
- update to 2.3.11.1

* Wed Aug 22 2012 Silvan Calarco <silvan.calarco@mambasoft.it> 2.3.11-1mamba
- update to 2.3.11

* Sun Jul 01 2012 Silvan Calarco <silvan.calarco@mambasoft.it> 2.3.10-1mamba
- update to 2.3.10

* Sun Jun 17 2012 Silvan Calarco <silvan.calarco@mambasoft.it> 2.3.9-1mamba
- update to 2.3.9

* Wed May 23 2012 Silvan Calarco <silvan.calarco@mambasoft.it> 2.3.8-1mamba
- update to 2.3.8
- require alsa-oss

* Tue May 15 2012 Silvan Calarco <silvan.calarco@mambasoft.it> 2.3.7-2mamba
- require ipheth to support iPhone tethering via USB cable

* Wed Apr 25 2012 Silvan Calarco <silvan.calarco@mambasoft.it> 2.3.7-1mamba
- update to 2.3.7

* Sun Apr 22 2012 Silvan Calarco <silvan.calarco@mambasoft.it> 2.3.6-1mamba
- update to 2.3.6

* Sun Apr 01 2012 Silvan Calarco <silvan.calarco@mambasoft.it> 2.3.5-2mamba
- require dmz-cursor-themes

* Mon Mar 12 2012 Silvan Calarco <silvan.calarco@mambasoft.it> 2.3.5-1mamba
- update to 2.3.5
- added requirement for usbinstall

* Sat Mar 03 2012 Silvan Calarco <silvan.calarco@mambasoft.it> 2.3.4-1mamba
- update to 2.3.4

* Wed Feb 29 2012 Silvan Calarco <silvan.calarco@mambasoft.it> 2.3.3-1mamba
- update to 2.3.3

* Tue Feb 28 2012 Silvan Calarco <silvan.calarco@mambasoft.it> 2.3.2-1mamba
- update to 2.3.2

* Sat Jan 21 2012 Silvan Calarco <silvan.calarco@mambasoft.it> 2.3.1-2mamba
- removed requirement for totem-mozilla-plugin

* Mon Jan 09 2012 Silvan Calarco <silvan.calarco@mambasoft.it> 2.3.1-1mamba
- update to 2.3.1

* Mon Dec 12 2011 Silvan Calarco <silvan.calarco@mambasoft.it> 2.3.0-1mamba
- update to 2.3.0

* Sun Dec 11 2011 Silvan Calarco <silvan.calarco@mambasoft.it> 2.2.37-2mamba
- removed requirements for alsaplayer and openmamba-sound-theme; set some arch conditional requirements

* Wed Nov 16 2011 Silvan Calarco <silvan.calarco@mambasoft.it> 2.2.37-1mamba
- update to 2.2.37

* Mon Nov 07 2011 Silvan Calarco <silvan.calarco@mambasoft.it> 2.2.36-1mamba
- update to 2.2.36

* Sat Nov 05 2011 Silvan Calarco <silvan.calarco@mambasoft.it> 2.2.35-1mamba
- update to 2.2.35
- added requirement for totem-mozilla-plugin

* Tue Nov 01 2011 Silvan Calarco <silvan.calarco@mambasoft.it> 2.2.34-1mamba
- update to 2.2.34

* Wed Oct 19 2011 Silvan Calarco <silvan.calarco@mambasoft.it> 2.2.33-1mamba
- update to 2.2.33

* Mon Oct 17 2011 Silvan Calarco <silvan.calarco@mambasoft.it> 2.2.32-1mamba
- update to 2.2.32
- system-base-openmamba: added requirement for smartmontools

* Mon Oct 10 2011 Silvan Calarco <silvan.calarco@mambasoft.it> 2.2.31-1mamba
- update to 2.2.31

* Thu Oct 06 2011 Silvan Calarco <silvan.calarco@mambasoft.it> 2.2.30-1mamba
- update to 2.2.30

* Sat Sep 24 2011 Silvan Calarco <silvan.calarco@mambasoft.it> 2.2.29-2mamba
- added requirements for postplug-xorg and postplug-sound

* Mon Sep 05 2011 Silvan Calarco <silvan.calarco@mambasoft.it> 2.2.29-1mamba
- update to 2.2.29

* Sat Sep 03 2011 Silvan Calarco <silvan.calarco@mambasoft.it> 2.2.28-1mamba
- update to 2.2.28

* Wed Aug 31 2011 Silvan Calarco <silvan.calarco@mambasoft.it> 2.2.27-1mamba
- update to 2.2.27

* Sun Aug 07 2011 Silvan Calarco <silvan.calarco@mambasoft.it> 2.2.26-1mamba
- update to 2.2.26

* Thu Jun 30 2011 Silvan Calarco <silvan.calarco@mambasoft.it> 2.2.25-1mamba
- update to 2.2.25

* Fri Jun 24 2011 Silvan Calarco <silvan.calarco@mambasoft.it> 2.2.24-1mamba
- update to 2.2.24
- desktop-base-openmamba: added requirement for /usr/bin/notify-send and license-dialog

* Tue Jun 07 2011 Silvan Calarco <silvan.calarco@mambasoft.it> 2.2.23-1mamba
- update to 2.2.23

* Thu Jun 02 2011 Silvan Calarco <silvan.calarco@mambasoft.it> 2.2.22-1mamba
- update to 2.2.22
- system-base-openmamba: added requirement for sudo

* Sun May 22 2011 Silvan Calarco <silvan.calarco@mambasoft.it> 2.2.21-1mamba
- update to 2.2.21

* Sat Apr 30 2011 Silvan Calarco <silvan.calarco@mambasoft.it> 2.2.20-2mamba
- moved requirement for grub-theme-openmamba to system-base-openmamba

* Tue Apr 26 2011 Silvan Calarco <silvan.calarco@mambasoft.it> 2.2.20-1mamba
- update to 2.2.20

* Sat Apr 23 2011 Silvan Calarco <silvan.calarco@mambasoft.it> 2.2.19-1mamba
- update to 2.2.19

* Tue Apr 19 2011 Silvan Calarco <silvan.calarco@mambasoft.it> 2.2.18-1mamba
- update to 2.2.18

* Tue Apr 19 2011 Silvan Calarco <silvan.calarco@mambasoft.it> 2.2.17-1mamba
- update to 2.2.17
- removed requirement for compiz screensaver
- added requirement for xscreensaver

* Mon Mar 21 2011 Silvan Calarco <silvan.calarco@mambasoft.it> 2.2.16-1mamba
- update to 2.2.16
- obsolete libflashsupport
- don't require desktop-base-kde4

* Fri Mar 18 2011 Silvan Calarco <silvan.calarco@mambasoft.it> 2.2.15-1mamba
- update to 2.2.15

* Sat Mar 12 2011 Silvan Calarco <silvan.calarco@mambasoft.it> 2.2.14-2mamba
- added requirement for pm-utils

* Thu Mar 10 2011 Silvan Calarco <silvan.calarco@mambasoft.it> 2.2.14-1mamba
- update to 2.2.14

* Thu Mar 10 2011 Silvan Calarco <silvan.calarco@mambasoft.it> 2.2.13-1mamba
- update to 2.2.13

* Wed Feb 16 2011 Silvan Calarco <silvan.calarco@mambasoft.it> 2.2.12-4mamba
- added virtual requirement for networkmanagergui

* Fri Jan 21 2011 Silvan Calarco <silvan.calarco@mambasoft.it> 2.2.12-3mamba
- remove requirements for moonlight and libflashsupport (better in pkggroups db)

* Thu Jan 20 2011 Silvan Calarco <silvan.calarco@mambasoft.it> 2.2.12-2mamba
- added requirement for moonlight

* Sun Dec 05 2010 Silvan Calarco <silvan.calarco@mambasoft.it> 2.2.12-1mamba
- update to 2.2.12

* Wed Nov 10 2010 Silvan Calarco <silvan.calarco@mambasoft.it> 2.2.11-1mamba
- update to 2.2.11

* Thu Oct 28 2010 Silvan Calarco <silvan.calarco@mambasoft.it> 2.2.10-1mamba
- update to 2.2.10

* Wed Oct 27 2010 Silvan Calarco <silvan.calarco@mambasoft.it> 2.2.9-1mamba
- update to 2.2.9

* Sat Oct 23 2010 Silvan Calarco <silvan.calarco@mambasoft.it> 2.2.8-1mamba
- update to 2.2.8

* Sun Sep 19 2010 Silvan Calarco <silvan.calarco@mambasoft.it> 2.2.7-1mamba
- update to 2.2.7

* Fri Sep 10 2010 Silvan Calarco <silvan.calarco@mambasoft.it> 2.2.6-2mamba
- added system-base-openmamba subpackage with non-graphical tools

* Wed Aug 25 2010 Silvan Calarco <silvan.calarco@mambasoft.it> 2.2.6-1mamba
- update to 2.2.6

* Fri Aug 13 2010 Silvan Calarco <silvan.calarco@mambasoft.it> 2.2.5-1mamba
- update to 2.2.5

* Sat Jul 24 2010 Silvan Calarco <silvan.calarco@mambasoft.it> 2.2.4-1mamba
- update to 2.2.4

* Wed Jul 21 2010 Silvan Calarco <silvan.calarco@mambasoft.it> 2.2.3-1mamba
- update to 2.2.3

* Fri Jun 18 2010 Silvan Calarco <silvan.calarco@mambasoft.it> 2.2.2-1mamba
- update to 2.2.2

* Wed May 26 2010 Silvan Calarco <silvan.calarco@mambasoft.it> 2.2.1-1mamba
- update to 2.2.1

* Wed Feb 24 2010 Silvan Calarco <silvan.calarco@mambasoft.it> 2.2-1mamba
- update to 2.2

* Fri Feb 19 2010 Silvan Calarco <silvan.calarco@mambasoft.it> 2.1.24-1mamba
- update to 2.1.24

* Sun Jan 03 2010 Silvan Calarco <silvan.calarco@mambasoft.it> 2.1.23-1mamba
- update to 2.1.23

* Wed Dec 30 2009 Silvan Calarco <silvan.calarco@mambasoft.it> 2.1.22-1mamba
- update to 2.1.22

* Mon Dec 21 2009 Silvan Calarco <silvan.calarco@mambasoft.it> 2.1.21-1mamba
- update to 2.1.21

* Thu Dec 03 2009 Silvan Calarco <silvan.calarco@mambasoft.it> 2.1.20-2mamba
- added requirement for desktop-base-kde4

* Fri Nov 20 2009 Silvan Calarco <silvan.calarco@mambasoft.it> 2.1.20-1mamba
- update to 2.1.20

* Thu Nov 12 2009 Silvan Calarco <silvan.calarco@mambasoft.it> 2.1.19-1mamba
- update to 2.1.19

* Thu Nov 12 2009 Silvan Calarco <silvan.calarco@mambasoft.it> 2.1.18-1mamba
- update to 2.1.18

* Wed Nov 04 2009 Silvan Calarco <silvan.calarco@mambasoft.it> 2.1.17-1mamba
- update to 2.1.17

* Sat Oct 31 2009 Silvan Calarco <silvan.calarco@mambasoft.it> 2.1.16-1mamba
- update to 2.1.16

* Tue Oct 20 2009 Silvan Calarco <silvan.calarco@mambasoft.it> 2.1.15-1mamba
- update to 2.1.15

* Sat Oct 10 2009 Silvan Calarco <silvan.calarco@mambasoft.it> 2.1.14-1mamba
- update to 2.1.14

* Sat Oct 10 2009 Silvan Calarco <silvan.calarco@mambasoft.it> 2.1.13-2mamba
- removed requirements for KDE3 theme packages
- added requirements for alsaplayer and alsaplayer-output-alsa

* Tue Sep 29 2009 Silvan Calarco <silvan.calarco@mambasoft.it> 2.1.13-1mamba
- update to 2.1.13

* Sun Sep 13 2009 Silvan Calarco <silvan.calarco@mambasoft.it> 2.1.12-1mamba
- update to 2.1.12

* Thu Sep 10 2009 Silvan Calarco <silvan.calarco@mambasoft.it> 2.1.11-1mamba
- update to 2.1.11

* Sat Sep 05 2009 Silvan Calarco <silvan.calarco@mambasoft.it> 2.1.10-1mamba
- update to 2.1.10

* Mon Aug 10 2009 Silvan Calarco <silvan.calarco@mambasoft.it> 2.1.9-1mamba
- update to 2.1.9

* Mon Aug 03 2009 Silvan Calarco <silvan.calarco@mambasoft.it> 2.1.8-1mamba
- update to 2.1.8

* Sun Jul 19 2009 Silvan Calarco <silvan.calarco@mambasoft.it> 2.1.7-1mamba
- update to 2.1.7

* Tue Jun 23 2009 Silvan Calarco <silvan.calarco@mambasoft.it> 2.1.6-1mamba
- update to 2.1.6

* Mon Jun 15 2009 Silvan Calarco <silvan.calarco@mambasoft.it> 2.1.5-1mamba
- update to 2.1.5

* Thu May 21 2009 Silvan Calarco <silvan.calarco@mambasoft.it> 2.1.4-1mamba
- update to 2.1.4

* Tue May 19 2009 Silvan Calarco <silvan.calarco@mambasoft.it> 2.1.3-1mamba
- update to 2.1.3

* Tue May 19 2009 Silvan Calarco <silvan.calarco@mambasoft.it> 2.1.2-2mamba
- added requirement for grub-theme-openmamba

* Tue May 12 2009 Silvan Calarco <silvan.calarco@mambasoft.it> 2.1.2-1mamba
- update to 2.1.2

* Tue Mar 31 2009 Silvan Calarco <silvan.calarco@mambasoft.it> 2.1.1-1mamba
- update to 2.1.1

* Thu Mar 05 2009 Silvan Calarco <silvan.calarco@mambasoft.it> 2.1.0-1mamba
- update to 2.1.0

* Tue Mar 03 2009 Silvan Calarco <silvan.calarco@mambasoft.it> 2.0.41-1mamba
- update to 2.0.41

* Sat Jan 31 2009 Silvan Calarco <silvan.calarco@mambasoft.it> 2.0.40-2mamba
- added requirement for kernelwireless

* Tue Jan 27 2009 Silvan Calarco <silvan.calarco@mambasoft.it> 2.0.40-1mamba
- update to 2.0.40

* Tue Jan 20 2009 Silvan Calarco <silvan.calarco@mambasoft.it> 2.0.39-1mamba
- update to 2.0.39

* Sun Jan 18 2009 Silvan Calarco <silvan.calarco@mambasoft.it> 2.0.38-1mamba
- update to 2.0.38

* Fri Jan 16 2009 Silvan Calarco <silvan.calarco@mambasoft.it> 2.0.37-1mamba
- update to 2.0.37

* Mon Jan 12 2009 Silvan Calarco <silvan.calarco@mambasoft.it> 2.0.36-2mamba
- added virtual requirement for kernelwireless

* Mon Jan 12 2009 Silvan Calarco <silvan.calarco@mambasoft.it> 2.0.36-1mamba
- update to 2.0.36

* Wed Jan 07 2009 Silvan Calarco <silvan.calarco@mambasoft.it> 2.0.35-1mamba
- update to 2.0.35

* Tue Dec 30 2008 Silvan Calarco <silvan.calarco@mambasoft.it> 2.0.34-1mamba
- update to 2.0.34

* Fri Dec 19 2008 Silvan Calarco <silvan.calarco@mambasoft.it> 2.0.33-2mamba
- added requirement for kernelsound

* Fri Dec 19 2008 Silvan Calarco <silvan.calarco@mambasoft.it> 2.0.33-1mamba
- update to 2.0.33

* Fri Dec 12 2008 Silvan Calarco <silvan.calarco@mambasoft.it> 2.0.32-1mamba
- update to 2.0.32

* Fri Dec 05 2008 Silvan Calarco <silvan.calarco@mambasoft.it> 2.0.31-1mamba
- update to 2.0.31

* Wed Oct 15 2008 Silvan Calarco <silvan.calarco@mambasoft.it> 2.0.30-1mamba
- update to 2.0.30

* Mon Sep 29 2008 Silvan Calarco <silvan.calarco@mambasoft.it> 2.0.29-2mamba
- added requirement for bash-completion

* Mon Sep 22 2008 Silvan Calarco <silvan.calarco@mambasoft.it> 2.0.29-1mamba
- update to 2.0.29
- added requirement for kicker-compiz

* Tue Sep 16 2008 Silvan Calarco <silvan.calarco@mambasoft.it> 2.0.28-1mamba
- update to 2.0.28

* Tue Sep 16 2008 Silvan Calarco <silvan.calarco@mambasoft.it> 2.0.27-2mamba
- update fixed (new kcmfonts file was not installed in 2.0.27-1mamba)

* Tue Sep 16 2008 Silvan Calarco <silvan.calarco@mambasoft.it> 2.0.27-1mamba
- update to 2.0.27

* Tue Jul 29 2008 Silvan Calarco <silvan.calarco@mambasoft.it> 2.0.26-1mamba
- update to 2.0.26

* Wed Jun 25 2008 Silvan Calarco <silvan.calarco@mambasoft.it> 2.0.25-1mamba
- update to 2.0.25

* Fri Jun 06 2008 Silvan Calarco <silvan.calarco@mambasoft.it> 2.0.24-1mamba
- update to 2.0.24

* Wed May 28 2008 Silvan Calarco <silvan.calarco@mambasoft.it> 2.0.23-1mamba
- update to 2.0.23

* Tue May 27 2008 Silvan Calarco <silvan.calarco@mambasoft.it> 2.0.22-1mamba
- update to 2.0.22

* Mon May 19 2008 Silvan Calarco <silvan.calarco@mambasoft.it> 2.0.21-1mamba
- update to 2.0.21

* Thu May 08 2008 Silvan Calarco <silvan.calarco@mambasoft.it> 2.0.20-1mamba
- update to 2.0.20

* Fri May 02 2008 Silvan Calarco <silvan.calarco@mambasoft.it> 2.0.19-1mamba
- update to 2.0.19

* Wed Apr 30 2008 Silvan Calarco <silvan.calarco@mambasoft.it> 2.0.18-1mamba
- update to 2.0.18

* Tue Apr 15 2008 Silvan Calarco <silvan.calarco@mambasoft.it> 2.0.17-1mamba
- update to 2.0.17

* Fri Apr 04 2008 Silvan Calarco <silvan.calarco@mambasoft.it> 2.0.16-1mamba
- update to 2.0.16

* Wed Mar 26 2008 Silvan Calarco <silvan.calarco@mambasoft.it> 2.0.15-1mamba
- update to 2.0.15

* Mon Mar 10 2008 Silvan Calarco <silvan.calarco@mambasoft.it> 2.0.14-1mamba
- update to 2.0.14

* Sun Mar 09 2008 Silvan Calarco <silvan.calarco@mambasoft.it> 2.0.13-1mamba
- update to 2.0.13

* Sat Mar 08 2008 Silvan Calarco <silvan.calarco@mambasoft.it> 2.0.12-1mamba
- update to 2.0.12

* Tue Feb 19 2008 Silvan Calarco <silvan.calarco@mambasoft.it> 2.0.11-1mamba
- update to 2.0.11

* Sat Feb 16 2008 Silvan Calarco <silvan.calarco@mambasoft.it> 2.0.10-1mamba
- update to 2.0.10

* Tue Feb 12 2008 Silvan Calarco <silvan.calarco@mambasoft.it> 2.0.9-1mamba
- update to 2.0.9

* Mon Feb 11 2008 Silvan Calarco <silvan.calarco@mambasoft.it> 2.0.8-1mamba
- update to 2.0.8

* Mon Feb 04 2008 Silvan Calarco <silvan.calarco@mambasoft.it> 2.0.7-1mamba
- update to 2.0.7

* Sat Feb 02 2008 Silvan Calarco <silvan.calarco@mambasoft.it> 2.0.6-1mamba
- update to 2.0.6

* Thu Jan 31 2008 Silvan Calarco <silvan.calarco@mambasoft.it> 2.0.5-2mamba
- scren saver support fix

* Thu Jan 31 2008 Silvan Calarco <silvan.calarco@mambasoft.it> 2.0.5-1mamba
- update to 2.0.5
- removed requirement for mambatray, added to mambabase base installs

* Wed Jan 16 2008 Silvan Calarco <silvan.calarco@mambasoft.it> 2.0.4-1mamba
- update to 2.0.4

* Fri Dec 28 2007 Silvan Calarco <silvan.calarco@mambasoft.it> 2.0.3-1mamba
- update to 2.0.3

* Thu Dec 27 2007 Silvan Calarco <silvan.calarco@mambasoft.it> 2.0.2-1mamba
- update to 2.0.2

* Thu Dec 27 2007 Silvan Calarco <silvan.calarco@mambasoft.it> 2.0.1-1mamba
- update to 2.0.1

* Wed Dec 26 2007 Silvan Calarco <silvan.calarco@mambasoft.it> 2.0-1mamba
- update to 2.0

* Thu Dec 20 2007 Silvan Calarco <silvan.calarco@mambasoft.it> 1.8.12-2mamba
- repackaged after fixing Makefile to apply recent changes

* Wed Dec 19 2007 Silvan Calarco <silvan.calarco@mambasoft.it> 1.8.12-1mamba
- update to 1.8.12

* Tue Dec 04 2007 Silvan Calarco <silvan.calarco@mambasoft.it> 1.8.11-3mamba
- added requirement for kdm-theme-openmamba

* Tue Dec 04 2007 Silvan Calarco <silvan.calarco@mambasoft.it> 1.8.11-2mamba
- added requirement for ksplash-theme-openmamba

* Mon Dec 03 2007 Silvan Calarco <silvan.calarco@mambasoft.it> 1.8.11-1mamba
- update to 1.8.11

* Sat Nov 24 2007 Silvan Calarco <silvan.calarco@mambasoft.it> 1.8.10-1mamba
- update to 1.8.10

* Sat Nov 17 2007 Silvan Calarco <silvan.calarco@mambasoft.it> 1.8.9-1mamba
- update to 1.8.9
- added requirement for mambatray

* Sat Nov 10 2007 Silvan Calarco <silvan.calarco@mambasoft.it> 1.8.8-1mamba
- update to 1.8.8

* Sat Nov 10 2007 Silvan Calarco <silvan.calarco@mambasoft.it> 1.8.7-1mamba
- update to 1.8.7

* Fri Nov 02 2007 Silvan Calarco <silvan.calarco@mambasoft.it> 1.8.6-1mamba
- update to 1.8.6

* Wed Oct 31 2007 Silvan Calarco <silvan.calarco@mambasoft.it> 1.8.5-1mamba
- update to 1.8.5

* Sun Oct 21 2007 Silvan Calarco <silvan.calarco@mambasoft.it> 1.8.4-1mamba
- update to 1.8.4

* Sun Oct 21 2007 Silvan Calarco <silvan.calarco@mambasoft.it> 1.8.3-1mamba
- update to 1.8.3

* Fri Oct 19 2007 Silvan Calarco <silvan.calarco@mambasoft.it> 1.8.2-1mamba
- update to 1.8.2

* Fri Oct 19 2007 Silvan Calarco <silvan.calarco@mambasoft.it> 1.8.1-1mamba
- update to 1.8.1

* Fri Oct 19 2007 Aleph0 <aleph0@openmamba.org> 1.8.0-2mamba
- specfile fixed

* Sat Oct 13 2007 Silvan Calarco <silvan.calarco@mambasoft.it> 1.8.0-1mamba
- update to 1.8.0

* Fri Oct 12 2007 Silvan Calarco <silvan.calarco@mambasoft.it> 1.7.6-4mamba
- added requirement for openmamba-release

* Fri Sep 28 2007 Silvan Calarco <silvan.calarco@mambasoft.it> 1.7.6-3mamba
- add requirement for openmamba-screensaver

* Fri Sep 28 2007 Silvan Calarco <silvan.calarco@mambasoft.it> 1.7.6-2mamba
- obsolete some old packages

* Thu Sep 20 2007 Silvan Calarco <silvan.calarco@mambasoft.it> 1.7.6-1mamba
- update to 1.7.6

* Sat Sep 01 2007 Silvan Calarco <silvan.calarco@mambasoft.it> 1.7.5-1mamba
- update to 1.7.5

* Fri Aug 31 2007 Silvan Calarco <silvan.calarco@mambasoft.it> 1.7.4-1mamba
- update to 1.7.4

* Sat Aug 25 2007 Silvan Calarco <silvan.calarco@mambasoft.it> 1.7.3-2mamba
- added requirement for /usr/bin/strip needed for rpms creation

* Mon Aug 13 2007 Silvan Calarco <silvan.calarco@mambasoft.it> 1.7.3-1mamba
- update to 1.7.3
- added requirements for diffutils and file

* Thu Aug 09 2007 Silvan Calarco <silvan.calarco@mambasoft.it> 1.7.2-1mamba
- update to 1.7.2 (flashplugin update to 9.0.48.0)

* Sat Jun 23 2007 Silvan Calarco <silvan.calarco@mambasoft.it> 1.7.1-1mamba
- update to 1.7.1
- added requirement for borealis-sound-theme

* Wed May 30 2007 Silvan Calarco <silvan.calarco@mambasoft.it> 1.7.0-3mamba
- added cabextract requirement needed by msttcorefonts specfile
- added curl requirement needed by win32codecs specfile

* Mon May 28 2007 Silvan Calarco <silvan.calarco@mambasoft.it> 1.7.0-2mamba
- added wget requirement needed by flash plugin specfile

* Sun May 13 2007 Silvan Calarco <silvan.calarco@mambasoft.it> 1.7.0-1mamba
- update to 1.7.0, added system wide theme openmamba green
- added requirement for ttf-bitstream-vera and ttf-freefont

* Sat Apr 28 2007 Silvan Calarco <silvan.calarco@mambasoft.it> 1.6.25-2mamba
- added requirement for libflashsupport

* Thu Mar 15 2007 Aleph0 <aleph0@openmamba.org> 1.6.25-1qilnx
- update to version 1.6.25 by autospec

* Sat Feb 10 2007 Aleph0 <aleph0@openmamba.org> 1.6.24-1qilnx
- update to version 1.6.24 by autospec

* Tue Feb 06 2007 Aleph0 <aleph0@openmamba.org> 1.6.23-1qilnx
- update to version 1.6.23 by autospec

* Thu Feb 01 2007 Aleph0 <aleph0@openmamba.org> 1.6.22-1qilnx
- update to version 1.6.22 by autospec

* Sun Dec 24 2006 Silvan Calarco <silvan.calarco@mambasoft.it> 1.6.21-1qilnx
- update to version 1.6.21 by autospec

* Tue Oct 31 2006 Davide Madrisan <davide.madrisan@qilinux.it> 1.6.20-1qilnx
- update to version 1.6.20 by autospec

* Tue Jul 18 2006 Massimo Pintore <massimo.pintore@qilinux.it> 1.6.19-1qilnx
- update to version 1.6.19 by autospec

* Wed Jul 12 2006 Davide Madrisan <davide.madrisan@qilinux.it> 1.6.18-3qilnx
- jre srpm: added "provides j2re"

* Thu Jul 06 2006 Davide Madrisan <davide.madrisan@qilinux.it> 1.6.18-2qilnx
- do not display build infos while rebuilding srpms packages

* Mon Jun 26 2006 Davide Madrisan <davide.madrisan@qilinux.it> 1.6.18-1qilnx
- update to version 1.6.18 by autospec

* Tue May 23 2006 Davide Madrisan <davide.madrisan@qilinux.it> 1.6.17-5qilnx
- requiremnt for curl moved to package qilinux-utils-common

* Mon May 22 2006 Davide Madrisan <davide.madrisan@qilinux.it> 1.6.17-4qilnx
- all common files moved to the common package

* Thu May 18 2006 Davide Madrisan <davide.madrisan@qilinux.it> 1.6.17-3qilnx
- qilinux-utils-free must provide the kdesktoprc configuration file

* Wed May 17 2006 Davide Madrisan <davide.madrisan@qilinux.it> 1.6.17-2qilnx
- added qilinux_release script
- qilinux-utils-common provides qilinux-utils

* Tue May 16 2006 Davide Madrisan <davide.madrisan@qilinux.it> 1.6.17-1qilnx
- update to version 1.6.17 by autospec

* Sat May 13 2006 Silvan Calarco <silvan.calarco@mambasoft.it> 1.6.16-1qilnx
- update to version 1.6.16 by autospec

* Thu May 11 2006 Silvan Calarco <silvan.calarco@mambasoft.it> 1.6.15-1qilnx
- update to version 1.6.15 by autospec

* Tue May 02 2006 Silvan Calarco <silvan.calarco@mambasoft.it> 1.6.14-1qilnx
- update to version 1.6.14 by autospec

* Wed Apr 05 2006 Silvan Calarco <silvan.calarco@mambasoft.it> 1.6.13-2qilnx
- create /etc/sysconfig/dna when missing

* Mon Apr 03 2006 Davide Madrisan <davide.madrisan@qilinux.it> 1.6.13-1qilnx
- update to version 1.6.13 by autospec

* Fri Mar 31 2006 Silvan Calarco <silvan.calarco@mambasoft.it> 1.6.12-1qilnx
- update to version 1.6.12 by autospec

* Fri Mar 31 2006 Silvan Calarco <silvan.calarco@mambasoft.it> 1.6.11-1qilnx
- update to version 1.6.11 by autospec

* Tue Mar 14 2006 Davide Madrisan <davide.madrisan@qilinux.it> 1.6.10-1qilnx
- update to version 1.6.10 by autospec
- comps.xml moved to qilinux-comps-<platform> packages

* Tue Mar 07 2006 Silvan Calarco <silvan.calarco@mambasoft.it> 1.6.9-1qilnx
- update to version 1.6.9 by autospec

* Mon Feb 27 2006 Silvan Calarco <silvan.calarco@mambasoft.it> 1.6.8-1qilnx
- update to version 1.6.8 by autospec

* Thu Feb 16 2006 Davide Madrisan <davide.madrisan@qilinux.it> 1.6.7-1qilnx
- update to version 1.6.7 by autospec

* Mon Feb 13 2006 Davide Madrisan <davide.madrisan@qilinux.it> 1.6.6-1qilnx
- update to version 1.6.6 by autospec

* Tue Feb 07 2006 Davide Madrisan <davide.madrisan@qilinux.it> 1.6.5-2qilnx
- this package requires curl

* Thu Feb 02 2006 Davide Madrisan <davide.madrisan@qilinux.it> 1.6.5-1qilnx
- update to version 1.6.5 by autospec

* Mon Nov 28 2005 Massimo Pintore <massimo.pintore@qilinux.it> 1.6.4-1qilnx
- update to version 1.6.4 by autospec

* Tue Sep 27 2005 Silvan Calarco <silvan.calarco@mambasoft.it> 1.6.3-1qilnx
- update to version 1.6.3 by autospec

* Mon Aug 29 2005 Silvan Calarco <silvan.calarco@mambasoft.it> 1.6.2-1qilnx
- update to version 1.6.2 by autospec

* Tue Aug 23 2005 Davide Madrisan <davide.madrisan@qilinux.it> 1.6.1-1qilnx
- update to version 1.6.1 by autospec

* Fri Aug 12 2005 Silvan Calarco <silvan.calarco@mambasoft.it> 1.6.0-1qilnx
- update to version 1.6.0 by autospec

* Thu Jul 07 2005 Silvan Calarco <silvan.calarco@mambasoft.it> 1.5.3-1qilnx
- update to version 1.5.3 by autospec

* Wed Jun 15 2005 Silvan Calarco <silvan.calarco@mambasoft.it> 1.5.2-1qilnx
- update to version 1.5.2 by autospec

* Fri May 06 2005 Silvan Calarco <silvan.calarco@mambasoft.it> 1.5.1-1qilnx
- update to version 1.5.1 by autospec

* Thu May 05 2005 Silvan Calarco <silvan.calarco@mambasoft.it> 1.5.0-1qilnx
- update to version 1.5.0 by autospec

* Wed May 04 2005 Silvan Calarco <silvan.calarco@mambasoft.it> 1.4.9-1qilnx
- update to version 1.4.9 by autospec

* Tue May 03 2005 Silvan Calarco <silvan.calarco@mambasoft.it> 1.4.8-1qilnx
- update to version 1.4.8 by autospec

* Mon May 02 2005 Silvan Calarco <silvan.calarco@mambasoft.it> 1.4.7-1qilnx
- update to version 1.4.7 by autospec

* Wed Apr 27 2005 Silvan Calarco <silvan.calarco@mambasoft.it> 1.4.6-1qilnx
- update to version 1.4.6 by autospec

* Wed Apr 27 2005 Silvan Calarco <silvan.calarco@mambasoft.it> 1.4.5-1qilnx
- update to version 1.4.5 by autospec

* Wed Apr 27 2005 Silvan Calarco <silvan.calarco@mambasoft.it> 1.4.4-1qilnx
- update to version 1.4.4 by autospec

* Tue Apr 26 2005 Silvan Calarco <silvan.calarco@mambasoft.it> 1.4.3-1qilnx
- update to version 1.4.3 by autospec

* Wed Apr 20 2005 Silvan Calarco <silvan.calarco@mambasoft.it> 1.4.2-1qilnx
- update to version 1.4.2 by autospec (added JRE installer)

* Tue Apr 19 2005 Silvan Calarco <silvan.calarco@mambasoft.it> 1.4.1-1qilnx
- update to version 1.4.1 by autospec

* Thu Mar 10 2005 Davide Madrisan <davide.madrisan@qilinux.it> 1.3.4-2qilnx
- rebuilt with new w32codecs srpms package
- added requirement for libcurl

* Tue Mar 08 2005 Silvan Calarco <silvan.calarco@mambasoft.it> 1.3.4-1qilnx
- update to version 1.3.4 by autospec

* Thu Mar 03 2005 Silvan Calarco <silvan.calarco@mambasoft.it> 1.3.3-1qilnx
- update to version 1.3.3 by autospec

* Sun Feb 27 2005 Silvan Calarco <silvan.calarco@mambasoft.it> 1.3.2-1qilnx
- new version build

* Fri Feb 25 2005 Silvan Calarco <silvan.calarco@mambasoft.it> 1.3.1-1qilnx
- new version build

* Wed Feb 23 2005 Davide Madrisan <davide.madrisan@qilinux.it> 1.3-1qilnx
- update to version 1.3 by autospec

* Mon Jan 31 2005 Silvan Calarco <silvan.calarco@mambasoft.it> 1.2-2qilnx
- minor fixes on startkde.firsttime

* Mon Jan 31 2005 Silvan Calarco <silvan.calarco@mambasoft.it> 1.2-1qilnx
- added startkde.firsttime script with default desktops and resourcebrowsing profile

* Sat Sep 25 2004 Silvan Calarco <silvan.calarco@mambasoft.it> 1.1-18qilnx
- qmailuseradd and qmailaliasadd scripts moved to qmail package

* Wed Aug 11 2004 Silvan Calarco <silvan.calarco@mambasoft.it> 1.1-17qilnx
- postplug moved to its own package

* Tue Aug 10 2004 Silvan Calarco <silvan.calarco@mambasoft.it> 1.1-16qilnx
- fix for 1.1-15 that was missing symlink

* Tue Aug 10 2004 Silvan Calarco <silvan.calarco@mambasoft.it> 1.1-15qilnx
- add postplug statically as a rcsysinit.d service (70)

* Mon Aug 09 2004 Silvan Calarco <silvan.calarco@mambasoft.it> 1.1-14qilnx
- added postplug localtime configuration dialog

* Mon Aug 09 2004 Silvan Calarco <silvan.calarco@mambasoft.it> 1.1-13qilnx
- added postplug boot time configuration tool with xorg and localtime scripts

* Mon Jul 19 2004 Silvan Calarco <silvan.calarco@mambasoft.it> 1.1-12qilnx
- fixed checks for ldap and ldap.secret for ldap_sysadmin_conf.sh execution

* Tue Jul 13 2004 Silvan Calarco <silvan.calarco@mambasoft.it> 1.1-11qilnx
- use ou=Groups instead of ou=Group for group entries
- ldap_sysadmin_conf.sh: minor fixes

* Mon Jul 12 2004 Silvan Calarco <silvan.calarco@mambasoft.it> 1.1-10qilnx
- renamed and fixed ldap_sysadmin_conf.sh script (was qilinux_ldap_conf.sh)

* Mon Jul 12 2004 Silvan Calarco <silvan.calarco@mambasoft.it> 1.1-9qilnx
- {user|group}{add|del}-qilinux renamed to *-ldap
- useradd-ldap: added options -s shell, -u uid and -g gid
- other minor fixes

* Sun Jul 11 2004 Silvan Calarco <silvan.calarco@mambasoft.it> 1.1-8qilnx
- some fixes on qilinux-useradd and other tools

* Fri Jul 09 2004 Silvan Calarco <silvan.calarco@mambasoft.it> 1.1-7qilnx
- added qilinux-useradd options to make it more similar to useradd

* Fri Jul 09 2004 Silvan Calarco <silvan.calarco@mambasoft.it> 1.1-6qilnx
- fixed qilinux-useradd and qilinux-userdel for new SysAdm addition with no ldap pw asked

* Fri Jul 09 2004 Silvan Calarco <silvan.calarco@mambasoft.it> 1.1-5qilnx
- add automatic execution of qiliunx_ldap_conf.sh if needed (should upgrade unpainfully)

* Fri Jul 09 2004 Silvan Calarco <silvan.calarco@mambasoft.it> 1.1-4qilnx
- added qilinux_ldap_conf.sh script
- added support for SysAdmin ldap user

* Mon Jun 08 2004 Silvan Calarco <silvan.calarco@mambasoft.it> 1.1-3qilnx
- ldappasswd renamed to ldapmgrpasswd because ldappasswd exists in /usr/bin

* Mon Jun 07 2004 Silvan Calarco <silvan.calarco@mambasoft.it> 1.1-2qilnx
- ldappasswd: preserve permissions of slapd.conf

* Mon Jun 07 2004 Silvan Calarco <silvan.calarco@mambasoft.it> 1.1-1qilnx
- added tool ldappasswd to change LDAP manager password
- release changed to 1.1

* Sat May 29 2004 Silvan Calarco <silvan.calarco@mambasoft.it> 1.0-12qilnx
- KDE logs menu added with tools

* Fri May 28 2004 Silvan Calarco <silvan.calarco@mambasoft.it> 1.0-11qilnx
- rebuild with new flash7 source rpm

* Tue May 25 2004 Silvan Calarco <silvan.calarco@mambasoft.it> 1.0-10qilnx
- added Makefile for package build and install
- added sysconfig defaults file and support in posixuseradd script

* Fri May 21 2004 Silvan Calarco <silvan.calarco@mambasoft.it> 1.0-9qilnx
- fixed wrong newlines in ldap-functions and qmailaliasadd

* Wed Mar 10 2004 Silvan Calarco <silvan.calarco@mambasoft.it> 1.0-8qilnx
- added msttcorefonts and flash SRPMS and KDE menu install entries

* Mon Mar 01 2004 Silvan Calarco <silvan.calarco@mambasoft.it> 1.0-7qilnx
- added qmailaliasadd script and ldap_qmailuser_exists

* Thu Feb 03 2004 Silvan Calarco <silvan.calarco@mambasoft.it> 1.0-6qilnx
- qmailuseradd enhancements and many fixes

* Wed Jan 21 2004 Silvan Calarco <silvan.calarco@mambasoft.it> 1.0-5qilnx
- new use of system ldap-functions with many bugfixes

* Tue Jan 20 2004 Silvan Calarco <silvan.calarco@mambasoft.it> 1.0-4qilnx
- DND information is now retrieved from /etc/ldap.conf instead of hostname -d

* Mon Nov 24 2003 Silvan Calarco <silvan.calarco@mambasoft.it> 1.0-3qilnx
- qmailuseradd: added support for ldapdefaultquota

* Fri Nov 07 2003 Silvan Calarco <silvan.calarco@mambasoft.it> 1.0-2qilnx
- added QiLinux kde menu
- added qinstall

* Wed Oct 08 2003 Silvan Calarco <silvan.calarco@mambasoft.it> 1.0-1qilnx
- first build
